package com.wily.profserv.logreader;

import java.io.PrintStream;

/**
 * @author Sylvain Gibassier
 * @copyright 2004-2005 Wily Technology, Inc.  All rights reserved.
 */

public class SimpleMatcher {
    static private final int TIME_TO_WAIT_BEFORE_CLEARING_MATCH = 30000;
    
    private final String metricName;
    private final String stringToMatch;
    private long lastMatchTimestamp = -1;
    private final PrintStream printStream;
    private boolean matchStatus = false;
    
    public SimpleMatcher(String mn,String stm,PrintStream ps) {
        metricName = mn;
        stringToMatch = stm.toLowerCase();
        printStream = ps;
        // initialize the metric with a value of 1
        printStream.println("<metric type=\"IntCounter\" name=\"" + metricName + "\" value=\"1\"/>");
    }
    
    /**
     * This method is going to clear the match statys if and only if more than
     * 30 seconds passed without a match
     * @param line
     */
    public void checkMatch(String line) {
        if (line.toLowerCase().indexOf(stringToMatch) != -1) {
            matchStatus = true;
            lastMatchTimestamp = System.currentTimeMillis();
            printStream.println("<metric type=\"IntCounter\" name=\"" + metricName + "\" value=\"2\"/>");
        } else {
            if (System.currentTimeMillis() > lastMatchTimestamp + TIME_TO_WAIT_BEFORE_CLEARING_MATCH) {
                matchStatus = false;
                printStream.println("<metric type=\"IntCounter\" name=\"" + metricName + "\" value=\"1\"/>");
            }
        }
    }

    /**
     * Clear the match status if necessary
     * Does not do anything otherwise
     */
    public void tick() {
        if (matchStatus && (System.currentTimeMillis() > lastMatchTimestamp + TIME_TO_WAIT_BEFORE_CLEARING_MATCH)) {
            matchStatus = false;
            printStream.println("<metric type=\"IntCounter\" name=\"" + metricName + "\" value=\"1\"/>");
        } 
    }

}
